/*
 * Copyright 2002-2013 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.security.config.annotation.web;

import javax.sql.DataSource;

import org.springframework.context.annotation.Bean;
import org.springframework.jdbc.datasource.embedded.EmbeddedDatabaseBuilder;
import org.springframework.jdbc.datasource.embedded.EmbeddedDatabaseType;
import org.springframework.ldap.core.support.BaseLdapPathContextSource;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.ldap.DefaultSpringSecurityContextSource;

/**
 * @author Rob Winch
 *
 */
public class WebSecurityConfigurerAdapterTestsConfigs {

	// necessary because groovy resolves incorrect method when using generics
	@EnableWebSecurity
	static class MessageSourcesPopulatedConfig extends WebSecurityConfigurerAdapter {
		// @formatter:off
		@Override
		protected void configure(HttpSecurity http) throws Exception {
			http
				.antMatcher("/role1/**")
				.authorizeRequests()
					.anyRequest().hasRole("1");
		}
		// @formatter:on

		@Bean
		public BaseLdapPathContextSource contextSource() throws Exception {
			DefaultSpringSecurityContextSource contextSource = new DefaultSpringSecurityContextSource(
					"ldap://127.0.0.1:33389/dc=springframework,dc=org");
			contextSource.setUserDn("uid=admin,ou=system");
			contextSource.setPassword("secret");
			return contextSource;
		}

		@Bean
		public DataSource dataSource() {
			EmbeddedDatabaseBuilder builder = new EmbeddedDatabaseBuilder();
			return builder.setType(EmbeddedDatabaseType.HSQL).build();
		}

		// @formatter:off
		@Override
		protected void configure(AuthenticationManagerBuilder auth) throws Exception {
			auth
				.inMemoryAuthentication().and()
				.jdbcAuthentication()
					.dataSource(dataSource())
					.and()
				.ldapAuthentication()
					.userDnPatterns("uid={0},ou=people")
					.contextSource(contextSource());
		}
		// @formatter:on
	}
}
